Key

Enum Key 

#[non_exhaustive]
#[repr(i32)]
pub enum Key {
Show 133 variants None = 0, Back = 2, Tab = 3, Return = 6, Pause = 7, CapsLock = 8, Escape = 13, Space = 18, PageUp = 19, PageDown = 20, End = 21, Home = 22, Left = 23, Up = 24, Right = 25, Down = 26, PrintScreen = 30, Insert = 31, Delete = 32, Help = 33, D0 = 34, D1 = 35, D2 = 36, D3 = 37, D4 = 38, D5 = 39, D6 = 40, D7 = 41, D8 = 42, D9 = 43, A = 44, B = 45, C = 46, D = 47, E = 48, F = 49, G = 50, H = 51, I = 52, J = 53, K = 54, L = 55, M = 56, N = 57, O = 58, P = 59, Q = 60, R = 61, S = 62, T = 63, U = 64, V = 65, W = 66, X = 67, Y = 68, Z = 69, LWin = 70, RWin = 71, Apps = 72, NumPad0 = 74, NumPad1 = 75, NumPad2 = 76, NumPad3 = 77, NumPad4 = 78, NumPad5 = 79, NumPad6 = 80, NumPad7 = 81, NumPad8 = 82, NumPad9 = 83, Multiply = 84, Add = 85, Subtract = 87, Decimal = 88, Divide = 89, F1 = 90, F2 = 91, F3 = 92, F4 = 93, F5 = 94, F6 = 95, F7 = 96, F8 = 97, F9 = 98, F10 = 99, F11 = 100, F12 = 101, F13 = 102, F14 = 103, F15 = 104, F16 = 105, F17 = 106, F18 = 107, F19 = 108, F20 = 109, F21 = 110, F22 = 111, F23 = 112, F24 = 113, NumLock = 114, ScrollLock = 115, LeftShift = 116, RightShift = 117, LeftCtrl = 118, RightCtrl = 119, LeftAlt = 120, RightAlt = 121, OemSemicolon = 140, OemPlus = 141, OemComma = 142, OemMinus = 143, OemPeriod = 144, OemSlash = 145, OemTilde = 146, OemOpenBrackets = 149, OemPipe = 150, OemCloseBrackets = 151, OemQuotes = 152, GamepadLeft = 175, GamepadUp = 176, GamepadRight = 177, GamepadDown = 178, GamepadAccept = 179, GamepadCancel = 180, GamepadMenu = 181, GamepadView = 182, GamepadPageUp = 183, GamepadPageDown = 184, GamepadPageLeft = 185, GamepadPageRight = 186, GamepadContext1 = 187, GamepadContext2 = 188, GamepadContext3 = 189, GamepadContext4 = 190,
}
Common subset of Noesis::Key from NsGui/InputEnums.h. Values are the C++ enum ordinals, validated by static_assert in noesis_view.cpp. View::key_down takes this typed enum, so a key outside the subset can’t be sent until it is added here — add the variant (with a matching assert in C++) to centralize the mapping.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0



Back = 2



Tab = 3



Return = 6



Pause = 7



CapsLock = 8



Escape = 13



Space = 18



PageUp = 19



PageDown = 20



End = 21



Home = 22



Left = 23



Up = 24



Right = 25



Down = 26



PrintScreen = 30



Insert = 31



Delete = 32



Help = 33



D0 = 34



D1 = 35



D2 = 36



D3 = 37



D4 = 38



D5 = 39



D6 = 40



D7 = 41



D8 = 42



D9 = 43



A = 44



B = 45



C = 46



D = 47



E = 48



F = 49



G = 50



H = 51



I = 52



J = 53



K = 54



L = 55



M = 56



N = 57



O = 58



P = 59



Q = 60



R = 61



S = 62



T = 63



U = 64



V = 65



W = 66



X = 67



Y = 68



Z = 69



LWin = 70



RWin = 71



Apps = 72



NumPad0 = 74



NumPad1 = 75



NumPad2 = 76



NumPad3 = 77



NumPad4 = 78



NumPad5 = 79



NumPad6 = 80



NumPad7 = 81



NumPad8 = 82



NumPad9 = 83



Multiply = 84



Add = 85



Subtract = 87



Decimal = 88



Divide = 89



F1 = 90



F2 = 91



F3 = 92



F4 = 93



F5 = 94



F6 = 95



F7 = 96



F8 = 97



F9 = 98



F10 = 99



F11 = 100



F12 = 101



F13 = 102



F14 = 103



F15 = 104



F16 = 105



F17 = 106



F18 = 107



F19 = 108



F20 = 109



F21 = 110



F22 = 111



F23 = 112



F24 = 113



NumLock = 114



ScrollLock = 115



LeftShift = 116



RightShift = 117



LeftCtrl = 118



RightCtrl = 119



LeftAlt = 120



RightAlt = 121



OemSemicolon = 140

Semicolon / colon on US layouts (Key_Oem1 / Key_OemSemicolon).



OemPlus = 141

= / + (Key_OemPlus).



OemComma = 142



OemMinus = 143



OemPeriod = 144



OemSlash = 145

/ / ? (Key_Oem2 / Key_OemQuestion).



OemTilde = 146

Backtick / tilde (Key_Oem3 / Key_OemTilde).



OemOpenBrackets = 149

[ / { (Key_Oem4 / Key_OemOpenBrackets).



OemPipe = 150

\ / | (Key_Oem5 / Key_OemPipe).



OemCloseBrackets = 151

] / } (Key_Oem6 / Key_OemCloseBrackets).



OemQuotes = 152

' / " (Key_Oem7 / Key_OemQuotes).



GamepadLeft = 175

Gamepad D-pad / left-stick left. Drives directional focus navigation (moves focus left) when the focused element uses Noesis directional nav.



GamepadUp = 176

Gamepad D-pad / left-stick up. Moves directional focus up.



GamepadRight = 177

Gamepad D-pad / left-stick right. Moves directional focus right.



GamepadDown = 178

Gamepad D-pad / left-stick down. Moves directional focus down.



GamepadAccept = 179

Gamepad A / accept button. Activates the focused control (like Return) and engages focus scopes.



GamepadCancel = 180

Gamepad B / cancel button. Cancels / disengages the current focus scope (like Escape).



GamepadMenu = 181

Gamepad menu / start button.



GamepadView = 182

Gamepad view / back button.



GamepadPageUp = 183

Gamepad page up (typically a shoulder/bumper), for paged scrolling.



GamepadPageDown = 184

Gamepad page down (typically a shoulder/bumper), for paged scrolling.



GamepadPageLeft = 185

Gamepad page left (typically a trigger), for horizontal paged scrolling.



GamepadPageRight = 186

Gamepad page right (typically a trigger), for horizontal paged scrolling.



GamepadContext1 = 187

Gamepad context-action button 1 (Key_GamepadContext1), free for app-defined bindings.



GamepadContext2 = 188

Gamepad context-action button 2 (Key_GamepadContext2).



GamepadContext3 = 189

Gamepad context-action button 3 (Key_GamepadContext3).



GamepadContext4 = 190

Gamepad context-action button 4 (Key_GamepadContext4).